import unittest
from colourise.main import complement_rgb


class TestComplementaryColours(unittest.TestCase):
    def test_black_complements_black(self):
        r, g, b = 0, 0, 0
        cr, cg, cb = complement_rgb(r, g, b)
        self.assertEqual(cr, 0)
        self.assertEqual(cg, 0)
        self.assertEqual(cb, 0)

    def test_white_complements_white(self):
        r, g, b = 255, 255, 255
        cr, cg, cb = complement_rgb(r, g, b)
        self.assertEqual(cr, 255)
        self.assertEqual(cg, 255)
        self.assertEqual(cb, 255)

    def test_red_complements_magenta(self):
        r, g, b = 255, 0, 0
        cr, cg, cb = complement_rgb(r, g, b)
        self.assertEqual(cr, 0)
        self.assertEqual(cg, 255)
        self.assertEqual(cb, 255)

    def test_blue_complements_yellow(self):
        r, g, b = 0, 0, 255
        cr, cg, cb = complement_rgb(r, g, b)
        self.assertEqual(cr, 255)
        self.assertEqual(cg, 255)
        self.assertEqual(cb, 0)

    def test_yellow_complements_blue(self):
        r, g, b = 255, 255, 0
        cr, cg, cb = complement_rgb(r, g, b)
        self.assertEqual(cr, 0)
        self.assertEqual(cg, 0)
        self.assertEqual(cb, 255)

    def _test_some_green_complements_pinkish(self):
        r, g, b = 60, 145, 78
        cr, cg, cb = complement_rgb(r, g, b)
        self.assertEqual(cr, 255)
        self.assertEqual(cg, 105)
        self.assertEqual(cb, 220)



import unittest
from colourise.main import rgb2hsl


class TestRGBtoHSL(unittest.TestCase):
    def test_primary_colour_red(self):
        r, g, b = 255, 0, 0
        h, s, l = rgb2hsl(r, g, b)
        self.assertEqual(h, 0.0)
        self.assertEqual(s, 1.0)
        self.assertEqual(l, 0.5)

    def test_primary_colour_green(self):
        r, g, b = 0, 255, 0
        h, s, l = rgb2hsl(r, g, b)
        self.assertEqual(h, 120.0)
        self.assertEqual(s, 1.0)
        self.assertEqual(l, 0.5)

    def test_primary_colour_blue(self):
        r, g, b = 0, 0, 255
        h, s, l = rgb2hsl(r, g, b)
        self.assertEqual(h, 240.0)
        self.assertEqual(s, 1.0)
        self.assertEqual(l, 0.5)

    def test_secondary_colour_cyan(self):
        r, g, b = 0, 255, 255
        h, s, l = rgb2hsl(r, g, b)
        self.assertAlmostEqual(h, 180.0, delta=0.15)
        self.assertEqual(s, 1.0)
        self.assertEqual(l, 0.5)

    def test_secondary_colour_magenta(self):
        r, g, b = 255, 0, 255
        h, s, l = rgb2hsl(r, g, b)
        self.assertAlmostEqual(h, 300.0, delta=0.15)
        self.assertEqual(s, 1.0)
        self.assertEqual(l, 0.5)

    def test_secondary_colour_yellow(self):
        r, g, b = 255, 255, 0
        h, s, l = rgb2hsl(r, g, b)
        self.assertAlmostEqual(h, 60.0, delta=0.15)
        self.assertEqual(s, 1.0)
        self.assertEqual(l, 0.5)

    def test_black(self):
        r, g, b = 0, 0, 0
        h, s, l = rgb2hsl(r, g, b)
        self.assertEqual(s, 0.0)
        self.assertEqual(s, 0.0)
        self.assertEqual(l, 0.0)

    def test_white(self):
        r, g, b = 255, 255, 255
        h, s, l = rgb2hsl(r, g, b)
        self.assertEqual(s, 0.0)
        self.assertEqual(s, 0.0)
        self.assertEqual(l, 1.0)



import unittest
from colourise.main import hsl2rgb


class TestHSLtoRGB(unittest.TestCase):
    def test_primary_colour_red(self):
        h, s, l = 0, 1, 0.5
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 255)
        self.assertEqual(g, 0)
        self.assertEqual(b, 0)

    def test_primary_colour_green(self):
        h, s, l = 120, 1, 0.5
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 0)
        self.assertEqual(g, 255)
        self.assertEqual(b, 0)

    def test_primary_colour_blue(self):
        h, s, l = 240, 1, 0.5
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 0)
        self.assertEqual(g, 0)
        self.assertEqual(b, 255)

    def test_secondary_colour_cyan(self):
        h, s, l = 180, 1, 0.5
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 0)
        self.assertEqual(g, 255)
        self.assertEqual(b, 255)

    def test_secondary_colour_yellow(self):
        h, s, l = 60, 1, 0.5
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 255)
        self.assertEqual(g, 255)
        self.assertEqual(b, 0)

    def test_secondary_colour_magenta(self):
        h, s, l = 300, 1, 0.5
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 255)
        self.assertEqual(g, 0)
        self.assertEqual(b, 255)

    def test_black(self):
        h, s, l = 0, 0, 0
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 0)
        self.assertEqual(g, 0)
        self.assertEqual(b, 0)

    def test_white(self):
        h, s, l = 0, 0, 1
        r, g, b = hsl2rgb(h, s, l)
        self.assertEqual(r, 255)
        self.assertEqual(g, 255)
        self.assertEqual(b, 255)



import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(
    name='colourise',
    version='0.0.2',
    author='Sander Huijsen',
    author_email='sander.huijsen@nmtafe.wa.edu.au',
    description='Package performing colour conversions',
    long_description=long_description,
    url='https://github.com/Sandyman/colourise',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
